@@ -167,17 +167,22 @@ class DocReadUtils:
 
         """
         if missing_treatment == "skip_if_any_missing":
-            def is_any_field_missing_in_doc(doc):
-                return all([self.is_field(f, doc) for f in fields])
-            docs = filter(is_any_field_missing_in_doc, docs)
-
+            docs = self.filter_docs_for_fields(fields, docs)
             return [self.get_fields_across_document(
                 fields, doc
             ) for doc in docs]
         return [self.get_fields_across_document(
             fields, doc, missing_treatment=missing_treatment)
             for doc in docs]
-    
+
+    def filter_docs_for_fields(self, fields: List, docs: List):
+        """
+        Filter for docs if they contain a list of fields
+        """
+        def is_any_field_missing_in_doc(doc):
+            return all([self.is_field(f, doc) for f in fields])
+        return filter(is_any_field_missing_in_doc, docs)
+        
     @classmethod
     def is_field(self, field: str, doc: Dict) -> bool:
         """
@@ -222,3 +227,48 @@ class DocReadUtils:
         """
         df = pd.json_normalize(doc, sep='.')
         return list(df.columns)
+
+    @classmethod
+    def subset_documents(
+        self,
+        fields: List[str], 
+        docs: List[Dict], 
+        missing_treatment: str='return_none'
+    ) -> List[Dict]:
+        """
+            Args:
+                fields:
+                    A list of fields of interest.
+                docs:
+                    A list of documents that may or may not have the chosen
+                    fields. 
+                missing_treatment:
+                    Cane be on of return_empty_string/return_none/raise_error
+            Example:
+                >>> from vectorai.client import ViClient
+                >>> vi_client = ViClient(username, api_key, vectorai_url)
+                >>> docs = [
+                ...     {"kfc": {"food": "chicken nuggets", "drink": "soda"}}
+                ...     {"mcd": {"food": "hamburger", "drink": "pop"}}
+                ... ]
+                >>> fields = [
+                ...     "kfc.food", "kfc.drink", "mcd.food", "mcd.drink"
+                ... ]
+                >>> vi_client.subset_documents(fields, docs) == [
+                ...     {
+                ...         "kfc.food": "chicken nuggets", "kfc.drink": "soda"},
+                ...         "mcd.food": "", "mcd.drink": ""
+                ...     },
+                ...     {
+                ...         "kfc.food": "", "kfc.drink": ""},
+                ...         "mcd.food": "hamburger", "mcd.drink": "pop"},
+                ...     }
+                ... ]
+        """
+        return [
+            {
+                field: self.get_field(
+                    field, doc, missing_treatment=missing_treatment
+                ) for field in fields
+            } for doc in docs
+        ]
